@@ -9,6 +9,7 @@ from .easyrip_main import (
     Global_val,
     Global_lang_val,
 )
+from .ripper import Media_info, Ass
 
 __all__ = [
     "init",
@@ -20,6 +21,8 @@ __all__ = [
     "check_ver",
     "Global_val",
     "Global_lang_val",
+    "Media_info",
+    "Ass",
 ]
 
 __version__ = Global_val.PROJECT_VERSION
